// --- Automatyczny reconnect po powrocie do karty/przywróceniu internetu ---
function reconnectIfNeeded() {
    if (!socket.connected) {
        socket.connect();
    }
}

document.addEventListener("visibilitychange", function() {
    if (!document.hidden) {
        reconnectIfNeeded();
    }
});

window.addEventListener("focus", function() {
    reconnectIfNeeded();
});

window.addEventListener("online", function() {
    reconnectIfNeeded();
});

// --- Blokowanie checkboxów na czas reconnect ---
function disableCheckboxes(disable) {
    document.querySelectorAll('#items input[type="checkbox"]').forEach(cb => {
        cb.disabled = disable;
    });
}

// --- Toasty przy rozłączeniu i połączeniu ---
let firstConnect = true;
let wasReconnected = false; // flaga do kontrolowania toasta

socket.on('connect', function() {
    if (!firstConnect) {
        showToast('Połączono z serwerem! 🔄', 'info');
        disableCheckboxes(true);
        wasReconnected = true;

        if (window.LIST_ID && window.usernameForReconnect) {
            showToast(`DEBUG: emituję join_list z LIST_ID=${window.LIST_ID}, username=${window.usernameForReconnect}`, 'warning');
            socket.emit('join_list', { room: window.LIST_ID, username: window.usernameForReconnect });
        } else {
            showToast('DEBUG: Brak LIST_ID lub username — nie wysyłam join_list!', 'danger');
        }
    }
    firstConnect = false;
});

socket.off('joined_confirmation');
socket.on('joined_confirmation', function(data) {
    showToast(`DEBUG: Odebrano joined_confirmation, room: ${data.room}`, 'success');
    if (wasReconnected) {
        showToast(`Lista: ${data.list_title} – ponownie dołączono.`, 'info');
        wasReconnected = false;
    }
    disableCheckboxes(false);
});
